MODULE_NAME='RGB_Spectrum_DualView_UI' (DEV vdvDEV, DEV dvTP)
(*{{PS_SOURCE_INFO(PROGRAM STATS)                          *)
(***********************************************************)
(*  FILE CREATED ON: 01/30/2003 AT: 08:51:36               *)
(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 07/15/2003 AT: 10:24:32         *)
(***********************************************************)
(*  ORPHAN_FILE_PLATFORM: 1                                *)
(***********************************************************)
(*!!FILE REVISION: Rev 0                                   *)
(*  REVISION DATE: 07/07/2003                              *)
(*                                                         *)
(*  COMMENTS:                                              *)
(*                                                         *)
(***********************************************************)
(*}}PS_SOURCE_INFO                                         *)
(***********************************************************)

(***********************************************************)
(* System Type : Netlinx                                   *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT
(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE
(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

VOLATILE CHAR sVERSION[5]           // STORES NETLINX COMM MODULE VERSION NUMBER
VOLATILE CHAR cKEYPAD_ENTRY[5] = '' // STORES THE NUMBER ENTERED ON THE TP KEYPAD
VOLATILE INTEGER nDEBUG = 0         // TRACKS THE ON/OFF STATE OF DEBUG MSGS SENT TO THE TELNET SESSION
VOLATILE INTEGER nCUR_INPUT = 0     // TRACKS THE CURRENTLY SELECTED INPUT
VOLATILE INTEGER nCUR_TYPE = 0      // TRACKS THE TYPE OF THE CURRENTLY SELECTED INPUT
VOLATILE INTEGER nPRESET = 0        // PRESET TO STORE/RECALL SETTINGS IN/FROM
VOLATILE INTEGER nENABLE_LEVEL = 1  // INDICATES WHEN ITS OK TO ACTIVATE THE TP LEVELS
VOLATILE INTEGER nDEVICE_SCALE = 0  // STORES THE ON/OFF STATE OF DEVICE SCALE
VOLATILE INTEGER nASPECT = 0        // STORES THE CURRENT ASPECT RATIO
VOLATILE INTEGER nFREEZE = 0        // STORES THE CURRENT INPUT'S FREEZE STATE
VOLATILE INTEGER nINPUTMODE = 0     // STORES THE CURRENT INPUT'S MODE
VOLATILE INTEGER nMAP = 0           // STORES THE CURRENT DISPLAY MAPPING
VOLATILE INTEGER nOPTIMIZE = 0      // STORES THE CURRENT STATE OF THE OUTPUT OPTIMIZATION
VOLATILE INTEGER nTEST_PATTERN = 0  // STORES THE ON/OFF STATE OF THE TEST PATTERN
VOLATILE INTEGER nVIDEO = 0         // STORES THE ON/OFF STATE OF THE CURRENT INPUT'S VIDEO WINDOW
VOLATILE SLONG slBRIGHTNESS = 0     // STORES THE CURRENT INPUT'S BRIGHTNESS LEVEL
VOLATILE SLONG slCONTRAST = 0       // STORES THE CURRENT INPUT'S CONTRAST LEVEL
VOLATILE SLONG slSHARPNESS = 0      // STORES THE CURRENT INPUT'S SHARPNESS LEVEL
VOLATILE SLONG slHUE = 0            // STORES THE CURRENT INPUT'S HUE LEVEL
VOLATILE SLONG slSATURATION = 0     // STORES THE CURRENT INPUT'S SATURATION LEVEL
VOLATILE FLOAT fGAMMA = 0.0         // STORES THE CURRENT GAMMA LEVEL
(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING
(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
DEFINE_FUNCTION SLONG Scale_Range(SLONG slNum_In, SLONG slMin_In, SLONG slMax_In, SLONG slMin_Out, SLONG slMax_Out)
{
    SLONG slRange_In
    SLONG slRange_Out
    SLONG slNum_Out

    IF (slNum_In < slMin_In OR slNum_In > slMax_In)
    {
        SEND_STRING 0, "'ERROR=Invalid value. Enter a value between ',ITOA(slMin_In),' and ',ITOA(slMax_In),'.'"
        Return -999
    }
    ELSE
    {
        slRange_In = slMax_In - slMin_In      // Establish input range
        slRange_Out = slMax_Out - slMin_Out   // Establish output range
        slNum_In = slNum_In - slMin_In        // Remove input offset
        slNum_Out = slNum_In * slRange_Out    // Multiply by max out range
        slNum_Out = slNum_Out / slRange_In    // Then divide by max in range
        slNum_Out = slNum_Out + slMin_Out     // Add in minimum output value
        Return slNum_Out
    }
}
DEFINE_FUNCTION FLOAT fScale_Range(FLOAT fNum_In, FLOAT fMin_In, FLOAT fMax_In, FLOAT fMin_Out, FLOAT fMax_Out)
{
    FLOAT fRange_In
    FLOAT fRange_Out
    FLOAT fNum_Out

    IF (fNum_In < fMin_In OR fNum_In > fMax_In)
    {
        SEND_STRING 0, "'ERROR=Invalid value. Enter a value between ',FTOA(fMin_In),' and ',FTOA(fMax_In),'.'"
        Return -999
    }
    ELSE
    {
        fRange_In = fMax_In - fMin_In      // Establish input range
        fRange_Out = fMax_Out - fMin_Out   // Establish output range
        fNum_In = fNum_In - fMin_In        // Remove input offset
        fNum_Out = fNum_In * fRange_Out    // Multiply by max out range
        fNum_Out = fNum_Out / fRange_In    // Then divide by max in range
        fNum_Out = fNum_Out + fMin_Out     // Add in minimum output value
        Return fNum_Out
    }
}
(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START
(***********************************************************)
(*                THE EVENTS GOES BELOW                    *)
(***********************************************************)
DEFINE_EVENT

DATA_EVENT[vdvDEV]
{
    STRING:
    {
        STACK_VAR CHAR cCMD[35]
        
        IF(nDEBUG) { SEND_STRING 0, "'UI RECEIVED FROM COMM: ',DATA.TEXT" }
        IF(FIND_STRING(DATA.TEXT, '=', 1)) { cCMD = REMOVE_STRING(DATA.TEXT, '=', 1) }        
        ELSE { cCMD = DATA.TEXT }
        SWITCH(cCMD)
        {
            CASE 'ASPECT=':
            {
                nASPECT = ATOI(DATA.TEXT)
            }
            CASE 'BAUD=': { SEND_COMMAND dvTP, "'@TXT',3,DATA.TEXT" } 
            CASE 'BRIGHTNESS=':
            {
                STACK_VAR INTEGER nINPUT
                
                slBRIGHTNESS = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',6,ITOA(slBRIGHTNESS),'%'" }
                    ELSE { SEND_COMMAND dvTP, "'@TXT',6,ITOA(slBRIGHTNESS)" }
                }
                IF ([dvTP, 6] AND nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slBRIGHTNESS),'%'"
                        SEND_LEVEL dvTP,1,slBRIGHTNESS*255/100
                    }
                    ELSE
                    {
                        STACK_VAR SLONG slVALUE
                        
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slBRIGHTNESS)"
                        slVALUE = slBRIGHTNESS
                        slVALUE = Scale_Range(slVALUE, -500, 500, 0, 100)
                        IF (slVALUE <> -999) { SEND_LEVEL dvTP,1,slVALUE*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'CONTRAST=':
            {
                STACK_VAR INTEGER nINPUT
                STACK_VAR SLONG slVALUE
                
                slCONTRAST = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',5,ITOA(slCONTRAST),'%'" }
                    ELSE { SEND_COMMAND dvTP, "'@TXT',5,ITOA(slCONTRAST)" }
                }
                IF ([dvTP, 5] AND nCUR_INPUT )
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slCONTRAST),'%'"
                        SEND_LEVEL dvTP,1,slCONTRAST*255/100
                    }
                    ELSE
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slCONTRAST)"
                        slVALUE = slCONTRAST
                        slVALUE = Scale_Range(slVALUE, 0, 200, 0, 100)
                        IF (slVALUE <> -999) { SEND_LEVEL dvTP,1,slVALUE*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'DEBUG=': { nDEBUG = ATOI(DATA.TEXT) }
            CASE 'DEVICE_SCALE=':
            {
                IF (nDEVICE_SCALE <> ATOI(DATA.TEXT))
                {
                    nDEVICE_SCALE = ATOI(DATA.TEXT)
                    IF (nCUR_INPUT > 0)
                    {
                        SEND_COMMAND vdvDEV, "'GAMMA?'"
                        SEND_COMMAND vdvDEV, "'HUE?',ITOA(nCUR_INPUT)"
                        SEND_COMMAND vdvDEV, "'SATURATION?',ITOA(nCUR_INPUT)"
                        SEND_COMMAND vdvDEV, "'SHARPNESS?',ITOA(nCUR_INPUT)"
                        SEND_COMMAND vdvDEV, "'CONTRAST?',ITOA(nCUR_INPUT)"
                        SEND_COMMAND vdvDEV, "'BRIGHTNESS?',ITOA(nCUR_INPUT)"
                    }
                }
            }
            CASE 'DOUBLE_BUFFER=':
            {
                STACK_VAR INTEGER nINPUT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':' ,1)
                IF (DATA.TEXT == 'OFF') {}
                ELSE IF (DATA.TEXT == 'ON') {}
            }
            CASE 'ERRORM=': { SEND_STRING 0, "'ERROR - ',DATA.TEXT" }
            CASE 'FADE=':
            {
                SWITCH(DATA.TEXT)
                {
                    CASE 'RGB1': {}
                    CASE 'RGB2': {}
                    CASE 'COMPOSITE': {}
                    CASE 'COMPONENT': {}
                    CASE 'SVIDEO': {}
                    CASE 'DVN': {}
                    CASE 'DVS': {}
                    CASE 'DVC': {}
                    CASE 'BLACK': {}
                }
            }
            CASE 'FADE_TIME=':
            {
                STACK_VAR FLOAT fTIME
                
                fTIME = ATOF(DATA.TEXT)
            }
            CASE 'FIRMWARE=': { SEND_COMMAND dvTP, "'@TXT',11,DATA.TEXT" }
            CASE 'FREEZE=':
            {
                STACK_VAR INTEGER nSTATE, nINPUT
                
                nSTATE = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nINPUT == nCUR_INPUT)
                {
                    nFREEZE = nSTATE
                }
            }
            CASE 'FULL_SCREEN=':
            {
                SWITCH(DATA.TEXT)
                {
                    CASE '0': {}
                    CASE '1': {}
                    CASE '2': {}
                }
            }
            CASE 'GAMMA=':
            {
                fGAMMA = ATOF(DATA.TEXT)
                IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',8,FORMAT('%1.0f',fGAMMA),'%'" }
                ELSE { SEND_COMMAND dvTP, "'@TXT',8,FORMAT('%1.2f',fGAMMA)" }
                IF ([dvTP, 8])
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,FORMAT('%1.0f',fGAMMA),'%'"
                        SEND_LEVEL dvTP,1,TYPE_CAST(fGAMMA)*255/100
                    }
                    ELSE
                    {
                        STACK_VAR FLOAT fVALUE
                        
                        SEND_COMMAND dvTP, "'@TXT',10,FORMAT('%1.2f',fGAMMA)"
                        fVALUE = fGAMMA
                        fVALUE = fScale_Range(fVALUE, 0.5, 2.0, 0, 100)
                        IF (fVALUE <> -999) { SEND_LEVEL dvTP,1,TYPE_CAST(fVALUE)*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'HUE=':
            {
                STACK_VAR INTEGER nINPUT
                
                slHUE = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nCUR_INPUT == nINPUT)
                {
                    IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',1,ITOA(slHUE),'%'" }
                    ELSE { SEND_COMMAND dvTP, "'@TXT',1,ITOA(slHUE)" }
                }
                IF ([dvTP, 1] AND nCUR_INPUT == nINPUT)
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slHUE),'%'"
                        SEND_LEVEL dvTP,1,slHUE*255/100
                    }
                    ELSE
                    {
                        STACK_VAR SLONG slVALUE

                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slHUE)"
                        slVALUE = slHUE
                        slVALUE = Scale_Range(slVALUE, -180, 180, 0, 100)
                        IF (slVALUE <> -999) { SEND_LEVEL dvTP,1,slVALUE*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'INPUT_MODE=':
            {
                STACK_VAR INTEGER nINPUT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                IF (nINPUT == nCUR_INPUT)
                {
                    SELECT
                    {
                        ACTIVE(FIND_STRING(DATA.TEXT, 'AUTO', 1)): { nINPUTMODE = 1 }
                        ACTIVE(FIND_STRING(DATA.TEXT, 'LOCK', 1)): { nINPUTMODE = 2 }
                        ACTIVE(FIND_STRING(DATA.TEXT, 'DEBUG',1)): { nINPUTMODE = 3 }
                    }
                }
            }
            CASE 'INPUT_NAME=':
            {
                STACK_VAR INTEGER nINPUT
                STACK_VAR CHAR sNAME[15]
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                sNAME = DATA.TEXT
            }
            CASE 'INPUT_TYPE=':
            {
                STACK_VAR INTEGER nINPUT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                SWITCH(DATA.TEXT)
                {
                    CASE 'COMPOSITE': { nCUR_TYPE = 1 }
                    CASE 'S-VIDEO': { nCUR_TYPE = 2 }
                    CASE 'COMPONENT': { nCUR_TYPE = 3 }
                    CASE 'RGB': { nCUR_TYPE = 4 }
                }
            }
            CASE 'INPUT_WINDOW=':
            {
                STACK_VAR INTEGER nINPUT, X, Y, nWIDTH, nHEIGHT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                X = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                Y = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nWIDTH = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nHEIGHT = ATOI(DATA.TEXT)
            }
            CASE 'MAP=':
            {
                STACK_VAR INTEGER nIN1, nIN2
                
                nIN1 = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nIN2 = ATOI(DATA.TEXT)
                IF (nIN1 == 1 AND nIN2 == 2) { nMAP = 1 }
                ELSE IF (nIN1 == 2 AND nIN2 == 1) { nMAP = 2 }
            }
            CASE 'OPTIMIZE_OUTPUT=':
            {
                IF (DATA.TEXT == '1') { nOPTIMIZE = 1 }
                ELSE IF (DATA.TEXT == '0') { nOPTIMIZE = 0 }
            }
            CASE 'OUTPUT_NAME=':
            {
                STACK_VAR CHAR sNAME[10]
                
                sNAME = DATA.TEXT
            }
            CASE 'OUTPUT_WINDOW=':
            {
                STACK_VAR INTEGER nINPUT, X, Y, nWIDTH, nHEIGHT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                X = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                Y = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nWIDTH = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nHEIGHT = ATOI(DATA.TEXT)
            }
            CASE 'OVER_SCAN=':
            {
                STACK_VAR INTEGER nINPUT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                IF (DATA.TEXT == 'OFF') {}
                ELSE IF (DATA.TEXT == 'ON') {}
            }
            CASE 'PIP=':
            {
                STACK_VAR INTEGER nIN1, nIN2, nWIDTH, nHEIGHT
                STACK_VAR SINTEGER X, Y
                
                nIN1 = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nIN2 = ATOI(DATA.TEXT)
                IF (FIND_STRING(DATA.TEXT, ':', 1))
                {
                    REMOVE_STRING(DATA.TEXT, ':', 1)
                    X = ATOI(DATA.TEXT)
                    REMOVE_STRING(DATA.TEXT, ':', 1)
                    Y = ATOI(DATA.TEXT)
                    REMOVE_STRING(DATA.TEXT, ':', 1)
                    nWIDTH = ATOI(DATA.TEXT)
                    REMOVE_STRING(DATA.TEXT, ':', 1)
                    nHEIGHT = ATOI(DATA.TEXT)
                }
            }
            CASE 'SATURATION=':
            {
                STACK_VAR INTEGER nINPUT
                STACK_VAR SLONG slVALUE
                
                slVALUE = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',9,ITOA(slVALUE),'%'" }
                    ELSE { SEND_COMMAND dvTP, "'@TXT',9,ITOA(slVALUE)" }
                    slSATURATION = slVALUE
                }
                IF ([dvTP, 9] AND nCUR_INPUT )
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slVALUE),'%'"
                        SEND_LEVEL dvTP,1,slVALUE*255/100
                    }
                    ELSE
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slVALUE)"
                        slVALUE = Scale_Range(slVALUE, 0, 200, 0, 100)
                        IF (slVALUE <> -999) { SEND_LEVEL dvTP,1,slVALUE*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'SHARPNESS=':
            {
                STACK_VAR INTEGER nINPUT
                STACK_VAR SLONG slVALUE
                
                slVALUE = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                nINPUT = ATOI(DATA.TEXT)
                IF (nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE) { SEND_COMMAND dvTP, "'@TXT',4,ITOA(slVALUE),'%'" }
                    ELSE { SEND_COMMAND dvTP, "'@TXT',4,ITOA(slVALUE)" }
                    slSHARPNESS = slVALUE
                }
                IF ([dvTP, 4] AND nINPUT == nCUR_INPUT)
                {
                    IF (!nDEVICE_SCALE)
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slVALUE),'%'"
                        SEND_LEVEL dvTP,1,slVALUE*255/100
                    }
                    ELSE
                    {
                        SEND_COMMAND dvTP, "'@TXT',10,ITOA(slVALUE)"
                        slVALUE = Scale_Range(slVALUE, 0, 3, 0, 100)
                        IF (slVALUE <> -999) { SEND_LEVEL dvTP,1,slVALUE*255/100 }
                    }
                    nENABLE_LEVEL=0
                    CANCEL_WAIT 'ENABLE LEVELS'
                    WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
                }
            }
            CASE 'TEST_PATTERN=':
            {
                STACK_VAR INTEGER N
                
                IF (ATOI(DATA.TEXT) == 1) { nTEST_PATTERN = 1 }
                ELSE { nTEST_PATTERN = 0 }
            }
            CASE 'VERSION=': { sVERSION = DATA.TEXT }
            CASE 'VIDEO=':
            {
                STACK_VAR INTEGER nINPUT
                
                nINPUT = ATOI(DATA.TEXT)
                REMOVE_STRING(DATA.TEXT, ':', 1)
                IF (nINPUT == nCUR_INPUT) { nVIDEO = ATOI(DATA.TEXT) }
            }
            CASE 'VIDEOMODE=':
            {
                STACK_VAR INTEGER nVAL
                
                nVAL = ATOI(DATA.TEXT)
                SELECT
                {
                    ACTIVE(nCUR_INPUT == 1 AND nVAL == 1): { SEND_COMMAND dvTP, "'@TXT',2,'NTSC'" }
                    ACTIVE(nCUR_INPUT == 1 AND nVAL == 2): { SEND_COMMAND dvTP, "'@TXT',2,'PAL'" }
                }
            }
        }// END SWITCH(cCMD)
    }// END STRING
}// END DATA_EVENT[vdvDEV]

DATA_EVENT[dvTP]
{
    ONLINE: 
    {
        STACK_VAR INTEGER I
        
        FOR(I = 1; I <= 255; I++) { SEND_COMMAND dvTP, "'@TXT',I,''" }
        SEND_COMMAND dvTP, "'@PPX'"
    }
}// END DATA_EVENT[dvTP]

LEVEL_EVENT[dvTP, 1]
{
    IF (nENABLE_LEVEL)
    {
        CANCEL_WAIT 'SEND NEW LEVEL'
        WAIT 2 'SEND NEW LEVEL'
        {
            SELECT
            {
                ACTIVE([dvTP, 1]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'HUE=',ITOA(LEVEL.VALUE*100/255),':',ITOA(nCUR_INPUT)"}
                    ELSE
                    {
                        LOCAL_VAR SLONG slVAL
                        
                        slVAL = Scale_Range(LEVEL.VALUE*100/255, 0, 100, -180, 180)
                        IF (slVAL <> -999) { SEND_COMMAND vdvDEV,"'HUE=',ITOA(slVAL),':',ITOA(nCUR_INPUT)" }
                        
                    }
                }
                ACTIVE([dvTP, 4]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'SHARPNESS=',ITOA(LEVEL.VALUE*100/255),':',ITOA(nCUR_INPUT)"}
                    ELSE
                    {
                        LOCAL_VAR SLONG slVAL
                        
                        slVAL = Scale_Range(LEVEL.VALUE*100/255, 0, 100, 0, 3)
                        IF (slVAL <> -999) { SEND_COMMAND vdvDEV,"'SHARPNESS=',ITOA(slVAL),':',ITOA(nCUR_INPUT)" }
                    }
                }
                ACTIVE([dvTP, 5]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'CONTRAST=',ITOA(LEVEL.VALUE*100/255),':',ITOA(nCUR_INPUT)" }
                    ELSE
                    {
                        LOCAL_VAR SLONG slVAL
                        
                        slVAL = Scale_Range(LEVEL.VALUE*100/255, 0, 100, 0, 200)
                        IF (slVAL <> -999) { SEND_COMMAND vdvDEV, "'CONTRAST=',ITOA(slVAL),':',ITOA(nCUR_INPUT)" }
                    }
                }
                ACTIVE([dvTP, 6]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'BRIGHTNESS=',ITOA(LEVEL.VALUE*100/255),':',ITOA(nCUR_INPUT)"}
                    ELSE
                    {
                        LOCAL_VAR SLONG slVAL
                        
                        slVAL = Scale_Range(LEVEL.VALUE*100/255, 0, 100, -500, 500)
                        IF (slVAL <> -999) { SEND_COMMAND vdvDEV,"'BRIGHTNESS=',ITOA(slVAL),':',ITOA(nCUR_INPUT)" }
                        
                    }
                }
                ACTIVE([dvTP, 8]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'GAMMA=',ITOA(LEVEL.VALUE*100/255)"}
                    ELSE
                    {
                        LOCAL_VAR FLOAT fVAL
                        
                        fVAL = fScale_Range(LEVEL.VALUE*100/255, 0, 100, 0.5, 2.0)
                        IF (fVAL <> -999) { SEND_COMMAND vdvDEV,"'GAMMA=',FORMAT('%1.2f',fVAL)" }
                        
                    }
                }
                ACTIVE([dvTP, 9]):
                {
                    IF(!nDEVICE_SCALE){SEND_COMMAND vdvDEV,"'SATURATION=',ITOA(LEVEL.VALUE*100/255),':',ITOA(nCUR_INPUT)"}
                    ELSE
                    {
                        LOCAL_VAR SLONG slVAL
                        
                        slVAL = Scale_Range(LEVEL.VALUE*100/255, 0, 100, 0, 200)
                        IF (slVAL <> -999) { SEND_COMMAND vdvDEV,"'SATURATION=',ITOA(slVAL),':',ITOA(nCUR_INPUT)" }
                        
                    }
                }
            }
        }
    }
}

BUTTON_EVENT[dvTP, 1]           // HUE BUTTON
BUTTON_EVENT[dvTP, 4]           // SHARPNESS BUTTON
BUTTON_EVENT[dvTP, 5]           // CONTRAST BUTTON
BUTTON_EVENT[dvTP, 6]           // BRIGHTNESS BUTTON
BUTTON_EVENT[dvTP, 8]           // GAMMA BUTTON
BUTTON_EVENT[dvTP, 9]           // SATURATION BUTTON
{
    PUSH:
    {
        OFF[dvTP, 1]
        OFF[dvTP, 4]
        OFF[dvTP, 5]
        OFF[dvTP, 6]
        OFF[dvTP, 8]
        OFF[dvTP, 9]
        ON[dvTP, BUTTON.INPUT.CHANNEL]
        SWITCH(BUTTON.INPUT.CHANNEL)
        {
            CASE 1:
            {
                IF(!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10, ITOA(slHUE),'%'"
                    SEND_LEVEL dvTP,1,slHUE*255/100
                }
                ELSE
                {
                    STACK_VAR SLONG slVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slHUE)"
                    slVAL = slHUE
                    slVAL = Scale_Range(slVAL, -180, 180, 0, 100)
                    SEND_LEVEL dvTP, 1, slVAL*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
            CASE 4:
            {
                IF (!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slSHARPNESS),'%'"
                    SEND_LEVEL dvTP,1,slSHARPNESS*255/100
                }
                ELSE
                {
                    STACK_VAR SLONG slVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slSHARPNESS)"
                    slVAL = slSHARPNESS
                    slVAL = Scale_Range(slVAL, 0, 3, 0, 100)
                    SEND_LEVEL dvTP,1,slVAL*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
            CASE 5:
            {
                IF (!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slCONTRAST),'%'"
                    SEND_LEVEL dvTP,1,slCONTRAST*255/100
                }
                ELSE
                {
                    STACK_VAR SLONG slVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slCONTRAST)"
                    slVAL = slCONTRAST
                    slVAL = Scale_Range(slVAL, 0, 200, 0, 100)
                    SEND_LEVEL dvTP,1,slVAL*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
            CASE 6:
            {
                IF (!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slBRIGHTNESS),'%'"
                    SEND_LEVEL dvTP,1,slBRIGHTNESS*255/100
                }
                ELSE 
                {
                    STACK_VAR SLONG slVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slBRIGHTNESS)"
                    slVAL = slBRIGHTNESS
                    slVAL = Scale_Range(slVAL, -500, 500, 0, 100)
                    SEND_LEVEL dvTP,1,slVAL*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
            CASE 8:
            {
                IF(!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10, FORMAT('%1.0f',fGAMMA),'%'"
                    SEND_LEVEL dvTP,1,TYPE_CAST(fGAMMA)*255/100
                }
                ELSE
                {
                    STACK_VAR FLOAT fVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,FORMAT('%1.2f',fGAMMA)"
                    fVAL = fGAMMA
                    fVAL = fScale_Range(fVAL, 0.5, 2.0, 0, 100)
                    SEND_LEVEL dvTP, 1, TYPE_CAST(fVAL)*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
            CASE 9:
            {
                IF(!nDEVICE_SCALE)
                {
                    SEND_COMMAND dvTP, "'@TXT',10, ITOA(slSATURATION),'%'"
                    SEND_LEVEL dvTP,1,slSATURATION*255/100
                }
                ELSE
                {
                    STACK_VAR SLONG slVAL
                    
                    SEND_COMMAND dvTP, "'@TXT',10,ITOA(slSATURATION)"
                    slVAL = slSATURATION
                    slVAL = Scale_Range(slVAL, 0, 200, 0, 100)
                    SEND_LEVEL dvTP, 1, slVAL*255/100
                }
                nENABLE_LEVEL=0
                CANCEL_WAIT 'ENABLE LEVELS'
                WAIT 3 'ENABLE LEVELS' { nENABLE_LEVEL = 1 } // REMOVES UNDESIRABLE ECHO FEEDBACK
            }
        }
    }
}

BUTTON_EVENT[dvTP, 11]          // current input 1 button
BUTTON_EVENT[dvTP, 12]          // current input 2 button
{
    PUSH:
    {
        OFF[dvTP, 11]
        OFF[dvTP, 12]
        ON[dvTP, BUTTON.INPUT.CHANNEL]
        nCUR_INPUT = BUTTON.INPUT.CHANNEL - 10
        SEND_COMMAND vdvDEV, "'INPUT_TYPE?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'FREEZE?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'VIDEO?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'BRIGHTNESS?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'CONTRAST?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'SHARPNESS?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'GAMMA?',ITOA(nCUR_INPUT)"
        SEND_COMMAND vdvDEV, "'INPUT_MODE?',ITOA(nCUR_INPUT)"
        IF (nCUR_TYPE <> 4)
        {
            SEND_COMMAND vdvDEV, "'SATURATION?',ITOA(nCUR_INPUT)"
            SEND_COMMAND vdvDEV, "'HUE?',ITOA(nCUR_INPUT)"
            SEND_COMMAND vdvDEV, "'VIDEOMODE?',ITOA(nCUR_INPUT)"   // IF NO INPUT SIGNAL IS PRESENT, THIS WILL RETURN ERROR
        }
        ELSE
        {
            SEND_COMMAND dvTP, "'@TXT',2,'---'"
            SEND_COMMAND dvTP, "'@TXT',9,'---%'"
            SEND_COMMAND dvTP, "'@TXT',10,'---%'"
        }
    }
}
BUTTON_EVENT[dvTP, 13]          // NORMAL ASPECT BUTTON
BUTTON_EVENT[dvTP, 14]          // STRETCHED ASPECT BUTTON
BUTTON_EVENT[dvTP, 15]          // CROPPSED ASPECT BUTTON
{
    PUSH:
    {
        PULSE[dvTP, BUTTON.INPUT.CHANNEL]
        SWITCH(BUTTON.INPUT.CHANNEL)
        {
            CASE 13: { SEND_STRING vdvDEV, "'ASPECT=1'" }
            CASE 14: { SEND_STRING vdvDEV, "'ASPECT=5'" }
            CASE 15: { SEND_STRING vdvDEV, "'ASPECT=6'" }
        }
    }
}
BUTTON_EVENT[dvTP, 16]          // MAP 1 | 2 BUTTON
BUTTON_EVENT[dvTP, 17]          // MAP 2 | 1 BUTTON
{
    PUSH:
    {
        PULSE[dvTP, BUTTON.INPUT.CHANNEL]
        IF (BUTTON.INPUT.CHANNEL == 16) { SEND_COMMAND vdvDEV, "'MAP=1:2'" }
        ELSE { SEND_COMMAND vdvDEV, "'MAP=2:1'" }
    }
}
BUTTON_EVENT[dvTP, 18]          // OPTIMIZE TOGGLE BUTTON
{
    PUSH:
    {
        IF ([dvTP, 18]) { SEND_COMMAND vdvDEV, "'OPTIMIZE_OUTPUT=0'" }
        ELSE { SEND_COMMAND vdvDEV, "'OPTIMIZE_OUTPUT=1'" }
    }
}
BUTTON_EVENT[dvTP, 20]          // FULL SCREEN BLACK BUTTON
BUTTON_EVENT[dvTP, 21]          // FULL SCREEN INPUT 1 BUTTON
BUTTON_EVENT[dvTP, 22]          // FULL SCREEN INPUT 2 BUTTON
{
    PUSH:
    {
        PULSE[dvTP, BUTTON.INPUT.CHANNEL]
        SEND_COMMAND vdvDEV, "'FULL_SCREEN=',ITOA(BUTTON.INPUT.CHANNEL - 20)"
    }
}
BUTTON_EVENT[dvTP, 23]          // FREEZE BUTTON
{
    PUSH:
    {
        IF ([dvTP, 23]) { SEND_COMMAND vdvDEV, "'FREEZE=0:',ITOA(nCUR_INPUT)" }
        ELSE { SEND_COMMAND vdvDEV, "'FREEZE=1:',ITOA(nCUR_INPUT)" }
    }
}
BUTTON_EVENT[dvTP, 24]          // WINDOW BUTTON
{
    PUSH:
    {
        IF ([dvTP, 24]) { SEND_COMMAND vdvDEV, "'VIDEO=',ITOA(nCUR_INPUT),':0'" }
        ELSE { SEND_COMMAND vdvDEV, "'VIDEO=',ITOA(nCUR_INPUT),':1'" }
    }
}

BUTTON_EVENT[dvTP, 27]          // LEVEL EXIT BUTTON
{
    PUSH:
    {
        OFF[dvTP, 1]            // HUE BUTTON
        OFF[dvTP, 4]            // SHARPNESS BUTTON
        OFF[dvTP, 5]            // CONTRAST BUTTON
        OFF[dvTP, 6]            // BRIGHTNESS BUTTON
        OFF[dvTP, 8]            // GAMMA BUTTON
        OFF[dvTP, 9]            // SATURATION BUTTON
    }
}

BUTTON_EVENT[dvTP, 30]          // COMPOSITE BUTTON
BUTTON_EVENT[dvTP, 31]          // COMPONENT BUTTON
BUTTON_EVENT[dvTP, 32]          // S-VIDEO BUTTON
BUTTON_EVENT[dvTP, 33]          // RGB BUTTON
{
    PUSH:
    {
        PULSE[dvTP, BUTTON.INPUT.CHANNEL]
        SWITCH(BUTTON.INPUT.CHANNEL)
        {
            CASE 30: { SEND_COMMAND vdvDEV, "'INPUT_TYPE=',ITOA(nCUR_INPUT),':COMPOSITE'" }
            CASE 31: { SEND_COMMAND vdvDEV, "'INPUT_TYPE=',ITOA(nCUR_INPUT),':COMPONENT'" }
            CASE 32: { SEND_COMMAND vdvDEV, "'INPUT_TYPE=',ITOA(nCUR_INPUT),':S-VIDEO'" }
            CASE 33: { SEND_COMMAND vdvDEV, "'INPUT_TYPE=',ITOA(nCUR_INPUT),':RGB'" }
        }
    }
}
BUTTON_EVENT[dvTP, 34]          // AUTO MODE BUTTON
BUTTON_EVENT[dvTP, 35]          // LOCK MODE BUTTON
BUTTON_EVENT[dvTP, 36]          // DEBUG MODE BUTTON
{
    PUSH:
    {
        SWITCH(BUTTON.INPUT.CHANNEL)
        {
            CASE 34: { SEND_COMMAND vdvDEV, "'INPUT_MODE=',ITOA(nCUR_INPUT),':AUTO'" }
            CASE 35: { SEND_COMMAND vdvDEV, "'INPUT_MODE=',ITOA(nCUR_INPUT),':LOCK'" }
            CASE 36: { SEND_COMMAND vdvDEV, "'INPUT_MODE=',ITOA(nCUR_INPUT),':DEBUG'" }
        }
    }
}

BUTTON_EVENT[dvTP, 52]          // TEST PATTERN BUTTON
{
    PUSH:
    {
        IF ([dvTP, 52]) { SEND_COMMAND vdvDEV, "'TEST_PATTERN=0'" }
        ELSE { SEND_COMMAND vdvDEV, "'TEST_PATTERN=1'" }
    }
}

BUTTON_EVENT[dvTP, 60]          // ENABLE/DISABLE PAN/TILT
BUTTON_EVENT[dvTP, 61]          // ENABLE/DISABLE ZOOM
BUTTON_EVENT[dvTP, 62]          // ENABLE/DISABLE POSITIONING
BUTTON_EVENT[dvTP, 63]          // ENABLE/DISABLE SIZING
{
    PUSH:
    {
        SELECT
        {
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 60):
            {
                SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':S'"
                OFF[dvTP, 60]
            }
            ACTIVE(BUTTON.INPUT.CHANNEL == 60 AND ![dvTP, 60] AND ![dvTP, 61] AND ![dvTP, 62] AND ![dvTP, 63]):
            {
                SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':E'"
                ON[dvTP, 60]
            }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 61):
            {
                SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':S'"
                OFF[dvTP, 61]
            }
            ACTIVE(BUTTON.INPUT.CHANNEL == 61 AND ![dvTP, 60] AND ![dvTP, 61] AND ![dvTP, 62] AND ![dvTP, 63]):
            {
                SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':E'"
                ON[dvTP, 61]
            }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 62):
            {
                SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':S'"
                OFF[dvTP, 62]
            }
            ACTIVE(BUTTON.INPUT.CHANNEL == 62 AND ![dvTP, 60] AND ![dvTP, 61] AND ![dvTP, 62] AND ![dvTP,63]):
            {
                SEND_COMMAND vdvDEV,"'MOVE=',ITOA(nCUR_INPUT),':E'"
                ON[dvTP, 62]
            }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 63):
            {
                SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':S'"
                OFF[dvTP, 63]
            }
            ACTIVE(BUTTON.INPUT.CHANNEL == 63 AND ![dvTP, 60] AND ![dvTP, 61] AND ![dvTP, 62] AND ![dvTP, 63]):
            {
                SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':E'"
                ON[dvTP, 63]
            }
            ACTIVE(1): { SEND_COMMAND dvTP, "'ABEEP'" }
        }
    }
}
BUTTON_EVENT[dvTP, 64]          // UP BUTTON
BUTTON_EVENT[dvTP, 65]          // DOWN BUTTON
BUTTON_EVENT[dvTP, 66]          // LEFT BUTTON
BUTTON_EVENT[dvTP, 67]          // RIGHT BUTTON
{
    PUSH:
    {
        TO[dvTP, BUTTON.INPUT.CHANNEL]
        SELECT
        {
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':5'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':1'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':7'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':<'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':3'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':>'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':+'" }
        }// END SELECT
    }// END PUSH
    HOLD[5, REPEAT]:
    {
        SELECT
        {
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':5'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 64): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':1'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 65): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':7'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':<'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 66): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':-'" }
            ACTIVE([dvTP, 60] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'PANTILT=',ITOA(nCUR_INPUT),':3'" }
            ACTIVE([dvTP, 61] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'ZOOM=',ITOA(nCUR_INPUT),':+'" }
            ACTIVE([dvTP, 62] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'MOVE=',ITOA(nCUR_INPUT),':>'" }
            ACTIVE([dvTP, 63] AND BUTTON.INPUT.CHANNEL == 67): { SEND_COMMAND vdvDEV, "'SIZE=',ITOA(nCUR_INPUT),':+'" }
        }// END SELECT
    }// END HOLD
}// END BUTTON_EVENT[dvTP, 64-67]

BUTTON_EVENT[dvTP, 70]          // RGB 1 BUTTON
BUTTON_EVENT[dvTP, 71]          // RGB 2 BUTTON
BUTTON_EVENT[dvTP, 72]          // BLACK BUTTON
BUTTON_EVENT[dvTP, 73]          // DVN BUTTON
BUTTON_EVENT[dvTP, 74]          // DVS BUTTON
BUTTON_EVENT[dvTP, 75]          // DVC BUTTON
BUTTON_EVENT[dvTP, 76]          // COMPOSITE BUTTON
BUTTON_EVENT[dvTP, 77]          // COMPONENT BUTTON
BUTTON_EVENT[dvTP, 78]          // S-VIDEO BUTTON
{
    PUSH:
    {
        PULSE[dvTP, BUTTON.INPUT.CHANNEL]
        SWITCH(BUTTON.INPUT.CHANNEL)
        {
            CASE 70: { SEND_COMMAND vdvDEV, "'FADE=RGB1'" }
            CASE 71: { SEND_COMMAND vdvDEV, "'FADE=RGB2'" }
            CASE 72: { SEND_COMMAND vdvDEV, "'FADE=BLACK'" }
            CASE 73: { SEND_COMMAND vdvDEV, "'FADE=DVN'" }
            CASE 74: { SEND_COMMAND vdvDEV, "'FADE=DVS'" }
            CASE 75: { SEND_COMMAND vdvDEV, "'FADE=DVC'" }
            CASE 76: { SEND_COMMAND vdvDEV, "'FADE=COMPOSITE'" }
            CASE 77: { SEND_COMMAND vdvDEV, "'FADE=COMPONENT'" }
            CASE 78: { SEND_COMMAND vdvDEV, "'FADE=SVIDEO'" }
        }
    }
}

BUTTON_EVENT[dvTP, 80]          // GLOBAL SAVE BUTTON
{
    PUSH:
    {
        PULSE[dvTP, 80]
        SEND_COMMAND vdvDEV, "'GLOBAL_SAVE'"
    }
}
(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

[dvTP, 13] = (nASPECT == 1)     // NORMAL ASPECT
[dvTP, 14] = (nASPECT == 5)     // STRETCHED ASPECT
[dvTP, 15] = (nASPECT == 6)     // CROPPED ASPECT

[dvTP, 16] = (nMAP == 1)        // MAP 1 | 2
[dvTP, 17] = (nMAP == 2)        // MAP 2 | 1

[dvTP, 18] = (nOPTIMIZE)        // OUTPUT OPTIMIZATION

[dvTP, 23] = (nFREEZE)          // FREEZE STATE
[dvTP, 24] = (nVIDEO)           // VIDEO WINDOW STATE

[dvTP, 30] = (nCUR_TYPE == 1)   // COMPOSITE INPUT TYPE
[dvTP, 31] = (nCUR_TYPE == 3)   // COMPONENT INPUT TYPE
[dvTP, 32] = (nCUR_TYPE == 2)   // S-VIDEO INPUT TYPE
[dvTP, 33] = (nCUR_TYPE == 4)   // RGB INPUT TYPE

[dvTP, 34] = (nINPUTMODE == 1)  // AUTO MODE
[dvTP, 35] = (nINPUTMODE == 2)  // LOCK MODE
[dvTP, 36] = (nINPUTMODE == 3)  // DEBUG MODE

[dvTP, 52] = (nTEST_PATTERN)    // TEST PATTERN STATE
(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)